@@ -1,7 +1,8 @@
+use log::{info, warn};
 use webp_animation::{Decoder, Encoder};
 
 fn main() {
-    env_logger::init();
+    env_logger::init_from_env(env_logger::Env::default().default_filter_or("info"));
 
     print_err(0, Encoder::new((0, 0)));
     let mut encoder = Encoder::new((1, 1)).unwrap();
@@ -19,14 +20,6 @@ fn main() {
             0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
         ]),
     );
-
-    #[cfg(feature = "image")]
-    {
-        let buffer = std::fs::read("./data/animated.webp").unwrap();
-        let decoder = Decoder::new(&buffer).unwrap();
-        let frame = decoder.into_iter().next().unwrap();
-        print_err(6, frame.into_bgra_image());
-    }
 }
 
 fn print_err<A, B>(num: usize, result: Result<A, B>)
@@ -34,9 +27,9 @@ where
     B: std::fmt::Debug,
 {
     match result {
-        Ok(_) => println!("Result {}: returned OK", num),
+        Ok(_) => info!("Result {}: returned OK", num),
         Err(e) => {
-            println!("Result {}: {:?}", num, e);
+            warn!("Result {}: {:?}", num, e);
         }
     }
 }
