@@ -316,24 +316,24 @@ mod tests {
     #[cfg(feature = "image")]
     #[test]
     fn test_decode_to_image() {
+        use std::io::Cursor;
+
         use image::{codecs::png::PngDecoder, DynamicImage, ImageDecoder as _, ImageOutputFormat};
 
         let buffer = get_animated_buffer();
         let decoder = Decoder::new(&buffer).unwrap();
         let mut iter = decoder.into_iter();
         let frame = iter.next().unwrap();
-        assert_eq!(
-            frame.into_bgra_image().unwrap_err(),
-            Error::WrongColorMode(ColorMode::Rgba, ColorMode::Bgra)
-        );
-        let frame = iter.next().unwrap();
         let image = frame.into_image().unwrap();
         assert_eq!(image.dimensions(), (400, 400));
 
-        let mut buf = Vec::new();
+        let mut buf = Cursor::new(Vec::new());
         DynamicImage::ImageRgba8(image)
             .write_to(&mut buf, ImageOutputFormat::Png)
             .unwrap();
+
+        let buf = buf.into_inner();
+
         let png_decoder = PngDecoder::new(&buf[..]).unwrap();
         assert_eq!(png_decoder.dimensions(), (400, 400));
     }
